# WOW_Tello

**프로젝트 개요**  
Tello Edu, Tello TT와 연동하여 드론을 제어할 수 있는 라이브러리이다.

단일 드론 제어 및 군집 드론도 활용할 수 있다.

드론의 기본 제어 및 미션패드 연동, 비행정보 수신, RC제어, 영상 수신 등 다양한 기능 탑재

화면을 받아서 처리하는 부분은 h264decoder가 필요하며, 해당 패키지는 직접 설치하여야 한다.


## Require
- Windows only
- Must install h264decoder(https://github.com/DaWelter/h264decoder)


## Getting Started
- Python3.6 버전 이상 파이썬 설치
- Visual Code 등으로 수정 가능
- 최종 및 안정화 버전은 PyPI에 업로드 할 수 있으며, 관련 방법은 사내에서 공유되는 자료를 확인
- h264decoder 설치 필요 - https://github.com/DaWelter/h264decoder

### Installing

WIP Library를 사용하기 위해선 아래의 명령어로 설치 가능하다.
```
pip install wowtello
```


### Versioning
* 업데이트 시 반드시 버전 관련 설정 수정할 것
* 버전 수정안할 시 업데이트 사항이 정상적으로 적용안될 수 있다.

## PyPI
(https://pypi.org/project/)

## Built With
* [이승명(nobu)](nobu1015@naver.com, nobu1015@wowsystem.co.kr)


## Contributiong / 기여

Please read [CONTRIBUTING.md](https://gist.github.com/PurpleBooth/b24679402957c63ec426) for details on our code of conduct, and the process for submitting pull requests to us. / [CONTRIBUTING.md](https://gist.github.com/PurpleBooth/b24679402957c63ec426) 를 읽고 이에 맞추어 pull request 를 해주세요.

## License / 라이센스
협의 필요

## Acknowledgments
* Thanks to DaWelter (https://github.com/DaWelter)
